@@ -19,8 +19,10 @@ public:
 	static constexpr const PhysicalOperatorType TYPE = PhysicalOperatorType::TRANSACTION;
 
 public:
-	explicit PhysicalTransaction(unique_ptr<TransactionInfo> info, idx_t estimated_cardinality)
-	    : PhysicalOperator(PhysicalOperatorType::TRANSACTION, {LogicalType::BOOLEAN}, estimated_cardinality),
+	explicit PhysicalTransaction(PhysicalPlan &physical_plan, unique_ptr<TransactionInfo> info,
+	                             idx_t estimated_cardinality)
+	    : PhysicalOperator(physical_plan, PhysicalOperatorType::TRANSACTION, {LogicalType::BOOLEAN},
+	                       estimated_cardinality),
 	      info(std::move(info)) {
 	}
 
